@@ -111,20 +111,33 @@ extern "C"
 #define ACVP_DH2048224 		0x0000000020000000ULL
 #define ACVP_DH2048256		0x0000000030000000ULL
 #define ACVP_RSA		0x0000000040000000ULL
-#define ACVP_ECDSA		0x0000000080000000ULL
-#define ACVP_DSA		0x0000000100000000ULL
-#define ACVP_DH			0x0000000200000000ULL
-#define ACVP_EDDSA		0x0000000400000000ULL
-#define ACVP_ECDH_ED		0x0000000800000000ULL
+#define ACVP_ECDSA		0x0000000050000000ULL
+#define ACVP_DSA		0x0000000060000000ULL
+#define ACVP_DH			0x0000000070000000ULL
+#define ACVP_EDDSA		0x0000000080000000ULL
+#define ACVP_ECDH_ED		0x0000000090000000ULL
+#define ACVP_SAFEPRIMES		0x00000000a0000000ULL
 
 #define ACVP_DRBGCTR		0x0000001000000000ULL
 #define ACVP_DRBGHMAC		0x0000002000000000ULL
 #define ACVP_DRBGHASH		0x0000003000000000ULL
-#define ACVP_DRBGMASK		0x000000f000000000ULL
+#define ACVP_DRBGMASK		0x0000003000000000ULL
 
-#define ACVP_AESCMAC 		0x0000010000000000ULL
-#define ACVP_TDESCMAC		0x0000020000000000ULL
-#define ACVP_CMACMASK		0x00000f0000000000ULL
+#define ACVP_AESCMAC 		0x0000004000000000ULL
+#define ACVP_TDESCMAC		0x0000008000000000ULL
+#define ACVP_CMACMASK		0x000000c000000000ULL
+
+#define ACVP_DH_MODP_2048	0x0000010000000000ULL
+#define ACVP_DH_MODP_3072	0x0000020000000000ULL
+#define ACVP_DH_MODP_4096	0x0000030000000000ULL
+#define ACVP_DH_MODP_6144	0x0000040000000000ULL
+#define ACVP_DH_MODP_8192	0x0000050000000000ULL
+#define ACVP_DH_FFDHE_2048	0x0000060000000000ULL
+#define ACVP_DH_FFDHE_3072	0x0000070000000000ULL
+#define ACVP_DH_FFDHE_4096	0x0000080000000000ULL
+#define ACVP_DH_FFDHE_6144	0x0000090000000000ULL
+#define ACVP_DH_FFDHE_8192	0x00000a0000000000ULL
+#define ACVP_SAFEPRIME_MASK	0x00000f0000000000ULL
 
 #define ACVP_KDF_COMPONENT	0x0000100000000000ULL
 #define ACVP_KDF_800_108	0x0000200000000000ULL
